@@ -4,16 +4,13 @@ from serviceregistry import ServiceRegistry
 from pythonioc import serviceproxy
 import inspect
 
-__version__ = "0.2.4"
+__version__ = "0.2.6"
 
 #
 # global instance, if the Service-Decorator is used for classes and instances.
 #
 __globalServiceRegistry = None
 
-def __serviceMetaClass(cls):
-    pass
-
 def __getGlobalServiceRegistry():
     global __globalServiceRegistry
     if not __globalServiceRegistry:
@@ -55,8 +52,8 @@ def Inject(service):
     return __getGlobalServiceRegistry()._getServiceProxy(service)
 
 
-def registerService(serviceClass, serviceName=None):
-    __getGlobalServiceRegistry().registerService(serviceClass, serviceName)
+def registerService(serviceClass, serviceName=None, overwrite=False):
+    __getGlobalServiceRegistry().registerService(serviceClass, serviceName, overwrite)
     
 def registerServiceInstance(instance, serviceName=None, overwrite=False):
     __getGlobalServiceRegistry().registerServiceInstance(instance, serviceName, overwrite)
@@ -67,3 +64,8 @@ def getService(service):
     """
     return __getGlobalServiceRegistry().getServiceInstance(service)
 
+def cleanServiceRegistry():
+    """
+    Removes all service instances from the global registry. Mainly for testing to start with a clean registry.
+    """
+    __getGlobalServiceRegistry().clean()
